# `pip install byeprint`

```python
from byeprint import p
```

From now just use `p()` and say bye to `print()` !

<details>
<summary>Acknowledgements</summary>

> [devtools](https://github.com/samuelcolvin/python-devtools)

</details>
